@@ -1,8 +1,13 @@
-"""Python wrapper for AWS E-Commerce Serive APIs.
+"""
+Python wrapper for AWS E-Commerce Serive APIs.
+
+URL: http://pyaws.sourceforge.net
 
 Based upon pyamazon (http://www.josephson.org/projects/pyamazon/) with 
 efforts to meet the latest AWS specification.
 
+Updated to support REST request signing requried after August 2009.
+
 The Amazon's web APIs specication is described here:
 http://www.amazon.com/webservices
 
@@ -19,23 +24,26 @@ License: Python Software Foundation License
 
 
 import os, urllib, string, inspect
+import hmac, hashlib, base64
 from xml.dom import minidom
+from time import gmtime, strftime
 
-__author__ = "Kun Xi < kunxi@kunxi.org >"
-__version__ = "0.2.0"
+__author__ = "Kun Xi < kunxi@kunxi.org >, Florian Demmer <fdemmer@gmail.com>"
+__version__ = "0.2.1"
 __license__ = "Python Software Foundation"
 
 
 """Package-wide variables:
 """
 LICENSE_KEY = None;
+SECRET_KEY = None;
 HTTP_PROXY = None
 LOCALE = "us"
 VERSION = "2007-02-22"
 
 __supportedLocales = {
-		None : "webservices.amazon.com",  
-		"us" : "webservices.amazon.com",   
+		None : "ecs.amazonaws.com",
+		"us" : "ecs.amazonaws.com",
 		"uk" : "webservices.amazon.co.uk",
 		"de" : "webservices.amazon.de",
 		"jp" : "webservices.amazon.co.jp",
@@ -49,12 +57,19 @@ __licenseKeys = (
 	(lambda key: os.environ.get('AWS_LICENSE_KEY', None))
    )
 
+__secretKeys = (
+	(lambda key: key),
+	(lambda key: SECRET_KEY), 
+	(lambda key: os.environ.get('AWS_SECRET_KEY', None))
+   )
+
 
 class AWSException(Exception) : 
 	'''Base class for all AWS exceptions'''
 	pass
 
 class NoLicenseKey(AWSException) : pass
+class NoSecretKey(AWSException) : pass
 class BadLocale(AWSException) : pass
 # Runtime exception
 class ExactParameterRequirement(AWSException): pass
@@ -76,14 +91,17 @@ class MinimumParameterRequirement(AWSException): pass
 class MissingOperationParameter(AWSException): pass
 class MissingParameterCombination(AWSException): pass
 class MissingParameters(AWSException): pass
+class MissingParameter(AWSException): pass
+class MissingClientTokenId(AWSException): pass
 class MissingParameterValueCombination(AWSException): pass
 class MissingServiceParameter(AWSException): pass
 class ParameterOutOfRange(AWSException): pass
 class ParameterRepeatedInRequest(AWSException): pass
 class RestrictedParameterValueCombination(AWSException): pass
 class XSLTTransformationError(AWSException): pass
+class SignatureDoesNotMatch(AWSException): pass
 
-class Bag : 
+class Bag(object): 
 	'''Wrapper class for DOM nodes'''
 	pass
 
@@ -131,7 +149,7 @@ def setLicenseKey(license_key=None):
 		if rc: 
 			LICENSE_KEY = rc;
 			return;
-	raise NoLicenseKey, ("Please get the license key from  http://www.amazon.com/webservices")
+	raise NoLicenseKey, ("Please get the license key from http://aws.amazon.com")
 
 
 def getLicenseKey():
@@ -140,23 +158,57 @@ def getLicenseKey():
 	if no license key is specified, BadLocale is raised."""
 
 	if not LICENSE_KEY:
-		raise NoLicenseKey, ("Please get the license key from  http://www.amazon.com/webservices")
+		raise NoLicenseKey, ("Please get the license key from http://aws.amazon.com")
 	return LICENSE_KEY
-	
+
+
+def setSecretKey(secret_key=None):
+	"""set secret key"""
+
+	global SECRET_KEY
+	for get in __secretKeys:
+		rc = get(secret_key)
+		if rc: 
+			SECRET_KEY = rc;
+			return;
+	raise NoSecretKey, ("Please get the secret key to your license key from http://aws.amazon.com")
+
+
+def getSecretKey():
+	"""get secret key"""
+
+	if not SECRET_KEY:
+		raise NoSecretKey, ("Please get the secret key to your license key from http://aws.amazon.com")
+	return SECRET_KEY
+
 
 def getVersion():
 	"""get version"""
 	return VERSION
 
-
-def buildRequest(argv):
+def buildRequest(argv, secret):
 	"""Build the REST request URL from argv,
 	
-	all key, value pairs in argv are quoted."""
-
-	url = "http://" + __supportedLocales[getLocale()] + "/onca/xml?Service=AWSECommerceService&"
-	return url + '&'.join(['%s=%s' % (k,urllib.quote(str(v))) for (k,v) in argv.items() if v]) 
+	all key, value pairs in argv are quoted.
 
+	includes quickfix for missing parameter signature:
+	http://richardcummings.info/the-request-must-contain-the-parameter-signature-quick-fix-for-your-php-rest-requests/
+	
+	also, this helped:
+	http://developer.amazonwebservices.com/connect/thread.jspa?messageID=142462
+	"""
+	host = __supportedLocales[getLocale()]
+	path = '/onca/xml'
+	param_list = ["Service=AWSECommerceService"]
+	param_list.extend(['%s=%s' % (k,urllib.quote(str(v))) for (k,v) in argv.items() if v])
+	if secret:
+		param_list.append("Timestamp=%s" % urllib.quote(strftime("%Y-%m-%dT%H:%M:%S.000Z", gmtime())))
+		param_list.sort()
+		message = "GET\n%s\n%s\n%s" % (host, path, '&'.join(param_list))
+		sig = base64.b64encode(hmac.new(secret, message, hashlib.sha256).digest())
+		param_list.append("Signature=%s" % urllib.quote(sig))
+	url = "http://%s%s?%s" % (host, path, '&'.join(param_list))
+	return url
 
 def buildException(els):
 	"""Build the exception from the returned DOM node
@@ -164,14 +216,15 @@ def buildException(els):
 	Only the first exception is raised."""
 
 	error = els[0]
-	class_name = error.childNodes[0].firstChild.data[4:]
-	msg = error.childNodes[1].firstChild.data 
+	class_name = error.childNodes[0].firstChild.data
+	msg = error.childNodes[1].firstChild.data
 
 	e = globals()[ class_name ](msg)
 	return e
 
 
 def query(url):
+	print url
 	"""Send the query url and return the DOM
 	
 	Exception is raised if there is errors"""
@@ -209,7 +262,7 @@ class wrappedIterator(list):
 	pass
 	
 
-class pagedIterator:
+class pagedIterator(object):
 	'''Return a page-based iterator'''
 
 	def __init__(self, XMLSearch, arguments, kwPage, kwItems, plugins=None):
@@ -337,7 +390,7 @@ def XMLItemLookup(ItemId, IdType=None, SearchIndex=None, MerchantId=None, Condit
 	Operation = "ItemLookup"
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 def ItemSearch(Keywords, SearchIndex="Blended", Availability=None, Title=None, Power=None, BrowseNode=None, Artist=None, Author=None, Actor=None, Director=None, AudienceRating=None, Manufacturer=None, MusicLabel=None, Composer=None, Publisher=None, Brand=None, Conductor=None, Orchestra=None, TextStream=None, ItemPage=None, Sort=None, City=None, Cuisine=None, Neighborhood=None, MinimumPrice=None, MaximumPrice=None, MerchantId=None, Condition=None, DeliveryMethod=None, ResponseGroup=None, AWSAccessKeyId=None):  
@@ -356,7 +409,7 @@ def XMLItemSearch(Keywords, SearchIndex="Blended", Availability=None, Title=None
 	Operation = "ItemSearch"
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 def SimilarityLookup(ItemId, SimilarityType=None, MerchantId=None, Condition=None, DeliveryMethod=None, ResponseGroup=None, AWSAccessKeyId=None):  
@@ -375,7 +428,7 @@ def XMLSimilarityLookup(ItemId, SimilarityType=None, MerchantId=None, Condition=
 	Operation = "SimilarityLookup"
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 # List Operations
@@ -396,7 +449,7 @@ def XMLListLookup(ListType, ListId, ProductPage=None, ProductGroup=None, Sort=No
 	Operation = "ListLookup"
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 def ListSearch(ListType, Name=None, FirstName=None, LastName=None, Email=None, City=None, State=None, ListPage=None, ResponseGroup=None, AWSAccessKeyId=None):
@@ -415,7 +468,7 @@ def XMLListSearch(ListType, Name=None, FirstName=None, LastName=None, Email=None
 	Operation = "ListSearch"
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 #Remote Shopping Cart Operations
@@ -436,7 +489,7 @@ def XMLCartCreate(Items, Quantities, ResponseGroup=None, AWSAccessKeyId=None):
 		del argv[x]
 
 	__fromListToItems(argv, Items, 'ASIN', Quantities)
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 def CartAdd(Cart, Items, Quantities, ResponseGroup=None, AWSAccessKeyId=None):
@@ -458,7 +511,7 @@ def XMLCartAdd(Cart, Items, Quantities, ResponseGroup=None, AWSAccessKeyId=None)
 		del argv[x]
 
 	__fromListToItems(argv, Items, 'ASIN', Quantities)
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 def CartGet(Cart, ResponseGroup=None, AWSAccessKeyId=None):
@@ -476,7 +529,7 @@ def XMLCartGet(Cart, ResponseGroup=None, AWSAccessKeyId=None):
 	HMAC = Cart.HMAC
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	del argv['Cart']
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 def CartModify(Cart, Items, Actions, ResponseGroup=None, AWSAccessKeyId=None):
@@ -497,7 +550,7 @@ def XMLCartModify(Cart, Items, Actions, ResponseGroup=None, AWSAccessKeyId=None)
 		del argv[x]
 
 	__fromListToItems(argv, Items, 'CartItemId', Actions)
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 	
 def CartClear(Cart, ResponseGroup=None, AWSAccessKeyId=None):
@@ -516,7 +569,7 @@ def XMLCartClear(Cart, ResponseGroup=None, AWSAccessKeyId=None):
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	del argv['Cart']
 
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 def __fromListToItems(argv, items, id, actions):
@@ -559,7 +612,7 @@ def XMLSellerLookup(Sellers, ResponseGroup=None, AWSAccessKeyId=None):
 	SellerId = ",".join(Sellers)
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
 	del argv['Sellers']
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 def SellerListingLookup(SellerId, Id, IdType="Listing", ResponseGroup=None, AWSAccessKeyId=None):
@@ -582,7 +635,7 @@ def XMLSellerListingLookup(SellerId, Id, IdType="Listing", ResponseGroup=None, A
 	Operation = "SellerListingLookup"
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 def SellerListingSearch(SellerId, Title=None, Sort=None, ListingPage=None, OfferStatus=None, ResponseGroup=None, AWSAccessKeyId=None):
@@ -601,7 +654,7 @@ def XMLSellerListingSearch(SellerId, Title=None, Sort=None, ListingPage=None, Of
 	Operation = "SellerListingSearch"
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 def CustomerContentSearch(Name=None, Email=None, CustomerPage=1, ResponseGroup=None, AWSAccessKeyId=None):
@@ -623,7 +676,7 @@ def XMLCustomerContentSearch(Name=None, Email=None, CustomerPage=1, ResponseGrou
 	for x in ('Name', 'Email'):
 		if not argv[x]:
 			del argv[x]
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 def CustomerContentLookup(CustomerId, ReviewPage=1, ResponseGroup=None, AWSAccessKeyId=None):
@@ -642,7 +695,7 @@ def XMLCustomerContentLookup(CustomerId, ReviewPage=1, ResponseGroup=None, AWSAc
 	Operation = "CustomerContentLookup"
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 # BrowseNode
@@ -662,7 +715,7 @@ def XMLBrowseNodeLookup(BrowseNodeId, ResponseGroup=None, AWSAccessKeyId=None):
 	Operation = "BrowseNodeLookup"
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 # Help
@@ -684,7 +737,7 @@ def XMLHelp(HelpType, About, ResponseGroup=None, AWSAccessKeyId=None):
 	Operation = "Help"
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
 # Transaction
@@ -705,9 +758,13 @@ def XMLTransactionLookup(TransactionId, ResponseGroup=None, AWSAccessKeyId=None)
 	Operation = "TransactionLookup"
 	AWSAccessKeyId = AWSAccessKeyId or LICENSE_KEY
 	argv = inspect.getargvalues(inspect.currentframe())[-1]
-	return query(buildRequest(argv))
+	return query(buildRequest(argv, SECRET_KEY))
 
 
+"""set default credentials
+"""
+setLicenseKey("AKIAJIHSIN6GMRQPWJKQ")
+setSecretKey("deE/T7lxPNplDDyw5MgroMosLIPlS+VdzcWIa147")
 
 if __name__ == "__main__" :
 	setLicenseKey("YOUR-LICENSE-HERE");
