@@ -25,7 +25,7 @@
 ###
 
 import gobject
-import md5
+from hashlib import md5
 import os
 import time
 from urllib import urlencode
@@ -56,7 +56,7 @@ class AudioScrobblerBadAuth(Exception):
 class AudioScrobblerBadSession(Exception):
     pass
 
-class _AudioScrobblerManager:
+class _AudioScrobblerManager(object):
     def __init__(self):
 
         self.password_hash = None
@@ -94,8 +94,8 @@ class _AudioScrobblerManager:
 
     def send_handshake(self):
     	timestamp=int(time.time())
-    	auth=md5.new(self.md5_pass+str(timestamp));
-    	authkey=auth.hexdigest()
+    	auth = md5(self.md5_pass+str(timestamp));
+    	authkey = auth.hexdigest()
         url = self.get_root_url() + "&u=%s&t=%s&a=%s" % (self.username,timestamp,authkey)
 
         print "Sending handshake to Audioscrobbler."
