@@ -185,7 +185,7 @@ class Config(gobject.GObject,Logger):
                 },
             "browser":
             {
-            "view":"2",
+            "view":"0",
             "local_num_cols":"3",
 
             "podcast_local_num_cols" : "1",
@@ -315,7 +315,7 @@ class Config(gobject.GObject,Logger):
             "plugins": {
                 "active_genericmanager":"Brasero",
                 "active_webradiomanager":"Shoutcast",
-                "active_sourcemanager":"\n".join(["Last.fm events","Lastfm Information","Context","Filesystem Browser","Web Radio support"]),
+                "active_sourcemanager":"\n".join(["yooook","Last.fm events","Lastfm Information","Context","Filesystem Browser","Web Radio support"]),
                     }
 
         }
