@@ -45,7 +45,7 @@ except: dbus_imported = False
 else: dbus_imported=True
 
 if not dbus_imported:
-    class ListenDBus:
+    class ListenDBus(object):
         def __init__(self,win,object_path="/org/gnome/listen"):
             self.win = win    
     print "No dbus support"
@@ -181,11 +181,11 @@ else:
 
         @dbus.service.method("org.gnome.Listen")
         def current_position(self):
-            return Player.get_position()/1000
+            return Player.get_position()
             
         @dbus.service.method("org.gnome.Listen")
         def current_song_length(self):
-            return Player.get_length()/1000
+            return Player.get_length()
 
         @dbus.service.method("org.gnome.Listen")
         def get_cover_path(self):
