@@ -85,9 +85,9 @@ class LastFmInfo(Logger):
             return
         status = root.attrib["status"]
         root = root.find("similarartists")
-        if status == "failed" and root:
-            error_code = root.getchildren()[0].attrib["code"]
-            error_str = root.getchildren()[0].text
+        if status == "failed" or not root:
+            #error_code = root.getchildren()[0].attrib["code"]
+            #error_str = root.getchildren()[0].text
             self.logwarn("failed artist.getsimilar for %s",artist)
             return
         else:
@@ -129,9 +129,9 @@ class LastFmInfo(Logger):
             return
         status = root.attrib["status"]
         root = root.find("topalbums")
-        if status == "failed" and root:
-            error_code = root.getchildren()[0].attrib["code"]
-            error_str = root.getchildren()[0].text
+        if status == "failed" or not root:
+            #error_code = root.getchildren()[0].attrib["code"]
+            #error_str = root.getchildren()[0].text
             self.logwarn("failed artist.gettopalbums for %s",artist)
             return
         else:
