@@ -248,6 +248,8 @@ class ListenDatabase(gobject.GObject,Logger):
 
                 s = Song(obj)
                 s.set_type(stype)
+                if self.__force_sanity_check:
+                    s["uri"] = vfs.realuri(s.get("uri"))
                 if s in self.__hiddens: 
                     self.__hiddens.remove(s)
                     del self.__songs[s.get("uri")]
@@ -505,6 +507,7 @@ class ListenDatabase(gobject.GObject,Logger):
         
     def reload_song_from_file(self, song):
         s = Song({"uri":song.get("uri")})
+        s["uri"] = vfs.realuri(s.get("uri"))
         s.read_from_file()
         s.sanitarize()
         new_tags = {}
@@ -601,17 +604,8 @@ class ListenDatabase(gobject.GObject,Logger):
     def create_autoplaylist(self, type, stype, name, infos=None):
         #TODO: add db_wrapper support
         pl = AutoPlaylist(stype, name, infos)
-
-        ret = True
-        if not infos:
-            from widget.smart_playlist import SmartPlaylistWindow
-            w = SmartPlaylistWindow(pl, True)
-            ret = w.run()
-
-        if ret: 
-            self.add_playlist(type, pl)
-            return pl
-        else : return None
+        self.add_playlist(type, pl)
+        return pl
 
     def get_playlists(self, type):
         return self.__playlists[type]
@@ -969,7 +963,7 @@ class ListenDBQuery(gobject.GObject,Logger):
     def get_songs(self, genres=[], artists=[], albums=[]):
         songs = set()
         if not genres and not artists and not albums: 
-            songs.update(self.__tree[1])
+            songs.update(self.__tree[1].copy())
         else:
             #if not genres: tmp_genres = self.__tree[0].keys()
             if not genres: tmp_genres = ["###ALL###"]
@@ -977,7 +971,7 @@ class ListenDBQuery(gobject.GObject,Logger):
             for genre in tmp_genres:
                 if not artists:
                     if not albums: 
-                        try: songs.update(self.__tree[0][genre][1])
+                        try: songs.update(self.__tree[0][genre][1].copy())
                         except KeyError: continue
                         continue
                     else:
@@ -987,12 +981,12 @@ class ListenDBQuery(gobject.GObject,Logger):
                 else: tmp_artists = artists 
                 for artist in tmp_artists:
                     if not albums:
-                        try: songs.update(self.__tree[0][genre][0][artist][1])
+                        try: songs.update(self.__tree[0][genre][0][artist][1].copy())
                         except KeyError: continue
                         continue
                     for album in albums:
                         try: 
-                            songs.update(self.__tree[0][genre][0][artist][0][album][1])
+                            songs.update(self.__tree[0][genre][0][artist][0][album][1].copy())
                         except KeyError: continue
         return songs
 
@@ -1001,7 +995,7 @@ class ListenDBQuery(gobject.GObject,Logger):
         infos = {}
         if key_request == "genre":
             try:
-                if key_values is None: mydict = self.__tree[0]
+                if key_values is None: mydict = self.__tree[0].copy()
                 else: 
                     mydict = {}
                     for value in key_values:
@@ -1026,7 +1020,7 @@ class ListenDBQuery(gobject.GObject,Logger):
             for genre in tmp_genres:
                 if key_request == "artist":
                     try:
-                        if key_values is None: mydict = self.__tree[0][genre][0]
+                        if key_values is None: mydict = self.__tree[0][genre][0].copy()
                         else:
                             mydict = {}
                             for value in key_values:
@@ -1052,7 +1046,7 @@ class ListenDBQuery(gobject.GObject,Logger):
                     for artist in tmp_artists:
                         if key_request == "album":
                             try:
-                                if key_values is None: mydict = self.__tree[0][genre][0][artist][0]
+                                if key_values is None: mydict = self.__tree[0][genre][0][artist][0].copy()
                                 else:
                                     mydict = {}
                                     for value in key_values:
