@@ -26,7 +26,7 @@ import gst.interfaces
 import sys
 
 from config import config
-from vfs import get_uris_from_asx, get_uris_from_m3u, get_uris_from_pls, get_mime_type
+from vfs import get_uris_from_asx, get_uris_from_m3u, get_uris_from_pls, get_mime_type, get_uris_from_xspf
 
 from helper import Dispatcher
 from library import ListenDB
@@ -150,7 +150,19 @@ class ListenPlayer(gobject.GObject,Logger):
         self.bin.disconnect(self.handler_notify_id)
 
     def on_tick(self, bin, pos, duration):
-        if not duration or duration <= 0: return
+        if not duration or duration <= 0:
+            if self.song:
+                duration = self.song.get("#duration")
+                if not duration:
+                    self.__can_catch_eos_with_tick = False
+                    return
+            else:
+                self.__can_catch_eos_with_tick = False
+                return
+        else:
+            if not self.song.get("#duration"):
+                ListenDB.set_property(self.song, {"#duration": duration * 1000})
+
         crossfade = self.get_crossfade()
         if crossfade < 0: crossfade = 0
         remaining = duration - pos
@@ -161,9 +173,9 @@ class ListenPlayer(gobject.GObject,Logger):
                     self.__signal_playend_emitted = False
                 else:
                     self.__signal_playend_emitted = True
-                self.next( gapless = True)
-                self.emit("play-end")
-        elif not crossfade and remaining < 0:
+                    self.next( gapless = True)
+                    self.emit("play-end")
+        elif not crossfade and remaining <= 0:
             # eos reached
             self.__signal_playend_emitted = False
             self.next( gapless = True )
@@ -179,6 +191,7 @@ class ListenPlayer(gobject.GObject,Logger):
         self.emit("paused")
         self.emit("play-end")
         self.next( gapless = True )
+        self.__signal_playend_emitted = False
     
     def set_song_reported(self):
         self.report_song = True
@@ -190,7 +203,7 @@ class ListenPlayer(gobject.GObject,Logger):
     def on_tag(self,bin, taglist):
         """ TAG wrapper for iRadio """
         #TODO: check this code
-        if self.song and not self.song.get("tagged") and ListenDB.song_has_capability(self.song,"gstreamer_tag_refresh"):
+        if self.song and not self.song.get("title") and ListenDB.song_has_capability(self.song,"gstreamer_tag_refresh"):
             IDS = {
                 "title": "artist",
                 #"genre": "genre",
@@ -282,7 +295,7 @@ class ListenPlayer(gobject.GObject,Logger):
             return True
 
         mime_type = get_mime_type(uri)
-        if mime_type in [ "audio/x-scpls", "audio/x-mpegurl", "video/x-ms-asf" ]:
+        if mime_type in [ "audio/x-scpls", "audio/x-mpegurl", "video/x-ms-asf", "application/xspf+xml" ]:
             # TODO: Read playlist need to be async
             ntry = 2
             uris = None
@@ -293,6 +306,8 @@ class ListenPlayer(gobject.GObject,Logger):
                     uris = get_uris_from_m3u(uri)
                 elif mime_type == "video/x-ms-asf":
                     uris = get_uris_from_asx(uri)
+                elif mime_type == "application/xspf+xml":
+                    uris = get_uris_from_xspf(uri)
                 ntry += 1
                 if ntry > 3: break
 
@@ -381,24 +396,24 @@ class ListenPlayer(gobject.GObject,Logger):
                 ListenDB.set_property(self.song , {"#stream_offset": p } )
             else:
                 p = p - self.song.get("#stream_offset")
-        return int(p*1000.0)
+        return int(p)
 
     def get_length(self):
-        if self.song!=None:
+        if self.song is not None:
             p = self.bin.xfade_get_duration()
-            if p != -1 and  not self.song.get("#duration"):
-                    ListenDB.set_property(self.song, {"#duration": p })
-            return p
-        else:
-            return 0
-
-
+            if p != -1:
+                if not self.song.get("#duration"):
+                    ListenDB.set_property(self.song, {"#duration": p * 1000})
+                return p
+            elif self.song.get("#duration"):
+                return self.song.get("#duration") / 1000
+        return 0
 
     def seek(self, pos):
         if self.song and self.song.get("uri").find("lastfm://")==0: return False
         if self.bin.xfade_seekable():
             self.__current_stream_seeked = True
-            pos = max(0, pos ) #int(pos/1000.0))
+            pos = max(0, pos )
             self.bin.xfade_set_time(pos)
             self.emit("seeked")
         else:
@@ -453,22 +468,34 @@ class ListenPlayer(gobject.GObject,Logger):
 
     def rewind(self):
         length = self.get_length()
-        jump = max(10000, length * 0.05)
+        if not length:
+            self.loginfo("Can't rewind a stream with no duration")
+            return 
+        jump = max(5, length * 0.05)
         pos = self.get_position()
-        if pos >= 0: self.seek(max(0, pos - jump) / 1000)
+        if pos >= 0:
+            pos = max(0, pos - jump)
+            self.seek(pos)
 
     def forward(self):
         length = self.get_length()
-        jump = max(10000, length * 0.05)
-        pos = self.get_position()
-        if pos >= 0: self.seek(min(pos + jump, length) / 1000 )
+        if not length:
+            self.loginfo("Can't forward a stream with no duration")
+            return 
+        jump = max(5, length * 0.05)
+        pos = float(self.get_position())
+        if pos >= 0: 
+            print pos, jump, length
+            pos = float(min(pos + jump, length)) 
+            self.logdebug("request seek to %d", pos)
+            self.seek(pos)
 
     def playpause(self):
-        self.logdebug("is paused ? %b",self.is_paused())
+        self.logdebug("is paused ? %s",self.is_paused())
         if not self.is_paused():
             self.pause()
         else:
-            self.logdebug("is playable ? %b",self.is_playable())
+            self.logdebug("is playable ? %s",self.is_playable())
             if self.is_playable():
                 self.play(-1)
             else:
