@@ -42,7 +42,7 @@
 #   silencebin ! adder ! outputbin 
 # 
 # * StreamBin *
-#   src [ ! queue ] ! decoder ! audioconvert ! audioresample ! capsfilter ! queue (preroll) ! volume (src pad ghosted)
+#   src [ ! queue ] ! decoder ! audioconvert ! rgvolume ! audioresample ! capsfilter ! queue (preroll) ! volume (src pad ghosted)
 #
 #
 # basic design (from rb code):
@@ -153,7 +153,7 @@
 import os
 import gobject
 import gst
-from threading import RLock
+from threading import Lock
 
 from logger import Logger
 
@@ -211,6 +211,9 @@ class PlayerBin(gobject.GObject,Logger):
         "buffering" : (gobject.SIGNAL_RUN_LAST,
                 gobject.TYPE_NONE,
                 (gobject.TYPE_INT, )),
+        "prepare-source" : (gobject.SIGNAL_RUN_LAST,
+                gobject.TYPE_NONE,
+                ()),
         "can-reuse-stream" : (gobject.SIGNAL_RUN_LAST,
                 gobject.TYPE_NONE,
                 (gobject.TYPE_STRING,gobject.TYPE_STRING, gobject.TYPE_PYOBJECT)),
@@ -233,8 +236,8 @@ class PlayerBin(gobject.GObject,Logger):
     def __init__(self):
         gobject.GObject.__init__(self)
 
-        self.stream_list_lock = RLock()
-        self.sink_lock = RLock()
+        self.stream_list_lock = Lock()
+        self.sink_lock = Lock()
 
         self.streams = []
         self.buffer_size = 64
@@ -344,19 +347,22 @@ class PlayerBin(gobject.GObject,Logger):
 
     def get_adder_pad(self):
         return self.__adder.get_request_pad("sink%d")
-
+    
+    # caller must hold stream lock
     def find_stream_by_uri(self, uri):
         if not uri: return None
         for stream in self.streams:
             if stream.uri == uri: return stream
         return None
 
+    # caller must hold stream lock
     def find_stream_by_state(self, state_mask):
         for stream in self.streams:
             if (stream.state & state_mask) != 0:
                 return stream
         return None
 
+    # caller must hold stream lock
     def find_stream_by_element(self, element):
         for stream in self.streams:
             e = element
@@ -636,6 +642,14 @@ class PlayerBin(gobject.GObject,Logger):
             duration = 0.0
         return duration
 
+    def xfade_get_current_uri(self):
+        ret = self.get_times_and_stream()
+        if ret:
+            stream, pos, duration = ret
+            return stream.uri
+        else:
+            return None
+
     def stop_sink_later(self):
 
         self.sink_lock.acquire()
@@ -683,7 +697,7 @@ class PlayerBin(gobject.GObject,Logger):
             if stream:
                 error = message.parse_error()[0]
                 if not stream.emitted_error and error.domain == gst.STREAM_ERROR and error.code == gst.STREAM_ERROR_FAILED:
-                    self.logerror("From stream: %s", message.parse_error())
+                    self.logerror("From stream: %s (%s)", error, message.parse_error()[1].replace("\n"," \ "))
                 stream.emitted_error = True
                 stream.emit_stream_error(message.parse_error())
         elif message.type == gst.MESSAGE_TAG:
@@ -726,9 +740,9 @@ class PlayerBin(gobject.GObject,Logger):
 
                 elif name == "STREAM_EOS_MESSAGE":
                     self.logdebug("got EOS message for stream %s -> PENDING_REMOVE", stream.cutted_uri)
+                    stream.needs_unlink = True
                     self.emit("eos",stream.uri)
                     stream.state = PENDING_REMOVE
-                    stream.needs_unlink = True
                     stream.unlink_blocked_cb(True)
                 else:
                     self.loginfo("got not managed message (%s) for stream %s",name,stream.cutted_uri)
@@ -749,6 +763,9 @@ class PlayerBin(gobject.GObject,Logger):
             #print message.type, message
             pass
 
+        # FIXME: missing in python need code it...
+        #bus.async_signal_func(message)
+
         return True
 
     def get_times_and_stream(self):
@@ -780,7 +797,7 @@ class PlayerBin(gobject.GObject,Logger):
                 try: 
                     res = stream.query_stream_position(gst.FORMAT_TIME)
                 except gst.QueryError:
-                    self.logerror(" failed query position")
+                    self.logerror(" failed query position from stream")
                     res = None
                 if res:
                     pos,format = res
@@ -789,7 +806,7 @@ class PlayerBin(gobject.GObject,Logger):
                 try: 
                     res = self.pipeline.query_position(gst.FORMAT_TIME)
                 except gst.QueryError:
-                    self.logerror(" failed query position")
+                    self.logerror(" failed query position from pipeline")
                     res = None
                 if res:
                     pos,format = res
@@ -1193,14 +1210,21 @@ class StreamBin(gst.Bin,Logger):
         self.__queue_threshold_id = None
         self.__queue_probe_id = None
         self.__adjust_probe_id = None
+        self.__decoder_pad = None
+
+        self.stream_data = None
+        self.stream_data_desktroy = None
+
         self.fading = False
         self.fade_end = 0
         self.emitted_error = False
         self.crossfade = 0
 
+        self.replaygain_scale = 1.0
+
         self.needs_unlink = False
 
-        self.lock = RLock()
+        self.lock = Lock()
 
         self.emitted_playing = False
         self.emitted_fake_playing = False
@@ -1233,8 +1257,11 @@ class StreamBin(gst.Bin,Logger):
                 try:self.__src.set_property("iradio-mode",True)
                 except : pass
 
-
-            self.__audioconvert = gst.element_factory_make ("audioconvert", None)
+            
+            self.__audioconvert1 = gst.element_factory_make ("audioconvert", None)
+            self.__replaygain_volume = gst.element_factory_make ("rgvolume", None)
+            self.__replaygain_volume.set_property("album-mode",True)
+            self.__audioconvert2 = gst.element_factory_make ("audioconvert", None)
             self.__audioresample = gst.element_factory_make ("audioresample", None)
             self.__capsfilter = gst.element_factory_make ("capsfilter", None)
             caps = gst.caps_from_string("audio/x-raw-int, channels=2, rate=44100, width=16, depth=16")
@@ -1275,19 +1302,19 @@ class StreamBin(gst.Bin,Logger):
 
             self.__underrun_id = self.__queue.connect("underrun", self.__queue_underrun_cb)
 
-            self.add(self.__src, self.__queue, self.__decoder, self.__audioconvert, \
+            self.add(self.__src, self.__queue, self.__decoder, self.__audioconvert1, self.__replaygain_volume, self.__audioconvert2, \
                     self.__audioresample, self.__capsfilter, self.__preroll, self.__volume)
             gst.element_link_many(self.__src, self.__queue, self.__decoder)
-            gst.element_link_many(self.__audioconvert, self.__audioresample, self.__capsfilter, \
+            gst.element_link_many(self.__audioconvert1, self.__replaygain_volume, self.__audioconvert2, self.__audioresample, self.__capsfilter, \
                     self.__preroll, self.__volume)
         else:
             self.logdebug("Create a local stream bin")
             self.__queue = None
 
-            self.add(self.__src, self.__decoder, self.__audioconvert, \
+            self.add(self.__src, self.__decoder, self.__audioconvert1, self.__replaygain_volume, self.__audioconvert2, \
                     self.__audioresample, self.__capsfilter, self.__preroll, self.__volume)
             gst.element_link_many(self.__src,  self.__decoder)
-            gst.element_link_many(self.__audioconvert, self.__audioresample, self.__capsfilter, \
+            gst.element_link_many(self.__audioconvert1, self.__replaygain_volume, self.__audioconvert2, self.__audioresample, self.__capsfilter, \
                     self.__preroll, self.__volume)
 
         #identity = gst.element_factory_make("identity")
@@ -1308,6 +1335,7 @@ class StreamBin(gst.Bin,Logger):
         if self.state == WAITING:       statename = "waiting"
         elif self.state == PLAYING:       statename = "playing"
         elif self.state == PAUSED:        statename = "paused"
+
         elif self.state == REUSING:       statename = "reusing"
         elif self.state == PREROLLING:    statename = "prerolling"
         elif self.state == PREROLL_PLAY:  statename = "preroll->play"
@@ -1317,8 +1345,9 @@ class StreamBin(gst.Bin,Logger):
         elif self.state == SEEKING_EOS:    statename = "seeking post EOS"
         elif self.state == WAITING_EOS:   statename = "waiting for EOS"
         elif self.state == FADING_OUT:    statename = "fading out"
-        elif self.state == PENDING_REMOVE:    statename = "pending remove"
         elif self.state == FADING_OUT_PAUSED:    statename = "fading->paused"
+
+        elif self.state == PENDING_REMOVE:    statename = "pending remove"
         else: statename = "Unknown!!"
         return statename
 
@@ -1328,7 +1357,7 @@ class StreamBin(gst.Bin,Logger):
         self.__error_id = None
 
     def emit_stream_error(self, error):
-        if self.__error_id != 0 : 
+        if self.__error_id : 
             pass
         else:
             self.__error = error
@@ -1516,16 +1545,16 @@ class StreamBin(gst.Bin,Logger):
 
         self.lock.release()
 
-        #self.__player.stream_list_lock.acquire()
         self.__player.linked_streams -= 1
         last = (self.__player.linked_streams == 0)
-        #self.__player.stream_list_lock.release()
         
         self.logdebug("%d linked streams left",self.__player.linked_streams)
         self.logdebug("unlink added in stream %s to block",self.cutted_uri)
         
         if stream_state == REUSING:
             self.reuse()
+            if not stream.link_and_unblock_stream():
+                stream.emit_stream_error("link_and_unblock_stream")
         else:
             if stream_state == SEEKING_PAUSED:
                 gobject.idle_add(self.perform_seek_idle)
@@ -1558,12 +1587,16 @@ class StreamBin(gst.Bin,Logger):
             self.__adjust_stream_base_time ()
         elif event.type in [ gst.EVENT_FLUSH_STOP, gst.EVENT_FLUSH_START ]:
             return False
+        elif event.type in [ gst.EVENT_LATENCY ]:
+            # Pass this signal silency
+            pass
         else:
             self.logdebug("event %s in stream %s", event.type, self.cutted_uri)
 
         return True
 
     def __adjust_base_time_probe_cb (self, pad, data):
+        self.logdebug("attempting to adjust base time for stream %s", self.cutted_uri)
         self.__adjust_stream_base_time()
         return True
 
@@ -1648,8 +1681,10 @@ class StreamBin(gst.Bin,Logger):
         if self.emitted_playing: return 
         s = gst.Structure("STREAM_PLAYING_MESSAGE")
         msg = gst.message_new_application(self,s)
-        if not fake: self.emitted_playing = True
-        else: self.logdebug("send a fake playing message")
+        if not fake: 
+            self.emitted_playing = True
+        else: 
+            self.logdebug("send a fake playing message")
         self.post_message(msg)
 
     def __new_decoded_pad_cb(self,decoder, pad, last):
@@ -1666,7 +1701,7 @@ class StreamBin(gst.Bin,Logger):
         elif self.__decoder_linked:
             self.logwarn("Decoder is already linked ?!!")
         else:
-            vpad = self.__audioconvert.get_pad("sink")
+            vpad = self.__audioconvert1.get_pad("sink")
             pad.link(vpad)
             self.__decoder_linked = True
             self.__decoder_pad = pad
@@ -1696,11 +1731,10 @@ class StreamBin(gst.Bin,Logger):
         if pos < 0: pos = 100000.0
         pos = float(pos)
 
-        time_start = pos
-        time_end = pos + time
+        start *= self.replaygain_scale
+        end *=  self.replaygain_scale
 
-
-        self.__volume.handler_block(self.__volume_signal_id)
+        self.__volume.handler_block_by_func(self.__volume_change_cb)
         self.__volume.set_passthrough(False)
 
         self.fade_end = end
@@ -1708,20 +1742,20 @@ class StreamBin(gst.Bin,Logger):
         self.__volume.set_property("volume",start)
         self.__fader.unset_all("volume")
 
-        if not self.__fader.set("volume", time_start , start):
+        if not self.__fader.set("volume", pos , start):
             self.logwarn("controller didn't like our start point")
 
         if not self.__fader.set("volume", 0.0 , start):
             self.logwarn("controller didn't like our 0 start point")
 
-        if not self.__fader.set("volume",time_end, end):
+        if not self.__fader.set("volume", pos + time,  end):
             self.logwarn("controller didn't like our end point")
  
-        self.__volume.handler_unblock(self.__volume_signal_id)
-        #self.logdebug("New Volume data: %s",self.__fader.get_data("volume"))
+        self.__volume.handler_unblock_by_func(self.__volume_change_cb)
 
         self.fading = True
         self.__volume.set_passthrough(False)
+        #self.logdebug("New Volume data: %s",self.__fader.get_data("volume"))
     
     def reuse(self):
         self.__player.emit("reuse-stream",self.new_uri,self.cutted_uri)
@@ -1919,4 +1953,18 @@ class StreamBin(gst.Bin,Logger):
     def post_eos_block_src_pad(self):
         # blocked must be True
         self.__src_pad.set_blocked_async(True,self.post_eos_seek_blocked_cb)
+    
+    def send_event(self, element, event):
+        ghost_pad = element.get_pad("src")
+        pad = ghost_pad.get_target()
+
+        ret = pad.get_parent().send_event(event)
+        return ret
+
+    def dispose_stream_data(self):
+        if self.stream_data and self.stream_data_desktroy:
+            self.stream_data_desktroy(self.stream_data)
+        self.stream_data = None
+        self.stream_data_desktroy = None
+
 
