@@ -34,8 +34,7 @@ import gst
 
 try:
     import avahi, dbus
-    if getattr(dbus, 'version', (0,0,0)) >= (0,41,0):
-        import dbus.glib
+    import dbus.glib
 except ImportError: dbus_imported = False
 else: dbus_imported=True
 
@@ -53,7 +52,7 @@ from logger import Logger
 from library import ListenDB
 from vfs import get_path_from_uri, makedirs
 
-import md5
+from hashlib import md5
 
 import plugins.generic.spydaap as spydaap
 from plugins.generic.spydaap import cache
@@ -91,7 +90,7 @@ urls = (
     )
 
 
-class ContentRangeFile:
+class ContentRangeFile(object):
     def __init__(self, parent, start, end=None, chunk=1024):
         self.parent = parent
         self.start = start
@@ -134,7 +133,7 @@ class ContainerCache(cache.OrderedCache):
             return d
         pid_list = []
         for pl in ListenDB.get_playlists("local"):
-            entries = [ md_cache.get_item_by_pid( md5.md5( get_path_from_uri(song.get("uri")) ).hexdigest() ) 
+            entries = [ md_cache.get_item_by_pid( md5( get_path_from_uri(song.get("uri")) ).hexdigest() ) 
                             for song in pl.get_songs()]
 
             #FIXME: For now i remove not cached song inteads of metadata
@@ -148,7 +147,7 @@ class ContainerCache(cache.OrderedCache):
                         [ build_do (md,id) for (id, md) in enumerate(entries) ])
                      ])
             ContainerCacheItem.write_entry(self.dir, str(pl.get_name()), d, len(entries))
-            pid_list.append(md5.md5(pl.name).hexdigest())
+            pid_list.append(md5(pl.name).hexdigest())
         self.build_index(pid_list)
 
 
@@ -160,7 +159,7 @@ class MetadataCache(cache.OrderedCache):
         songs = ListenDB.get_songs("local")
         for song in songs:
             ffn = get_path_from_uri(song.get("uri"))
-            digest = md5.md5(ffn).hexdigest()
+            digest = md5(ffn).hexdigest()
             marked[digest] = True
             md = self.get_item_by_pid(digest)
             if (not(md.get_exists()) or \
