@@ -42,8 +42,6 @@ else:
     except: print "No musicbrainz support (tunepimp missing or version < 0.5) "
     else: MUSICBRAINZ = True
 
-PLAYLIST_EXTENTION = [".m3u",".pls"]
-
 import utils
 import vfs
 from logger import Logger
@@ -143,14 +141,14 @@ For iradio:
 listen tag list: (need to be more clean)
 """
 USED_KEYS="""
+==song_type==
 uri station info_supp
 #track title artist album genre #duration #progress podcast_local_uri #disc
-#playcount #skipcount #lastplayed #added #date date
+#playcount #skipcount #lastplayed #added #date date year
 description descriptionrss podcast_feed_url hidden
 #mtime #ctime #rate 
 album_cover_url station_track_url
 #progress radio_person
-==song_type==
 #bitrate
 #size
 #stream_offset 
@@ -162,10 +160,18 @@ KEY_TYPES= {
     }
 
 class Song(dict, Logger):
+    def __init__(self, otherdict = None):
+        dict.__init__(self)
+        if otherdict:
+            for key in USED_KEYS:
+                default = key[0] == 0 and 0 or None
+                self[key] = otherdict.get(key,None)
+
     def get_dict(self):
         odict = {}
-        for key,value in self.copy().iteritems ():
-            odict[key] = value
+        for key, value in self.iteritems():
+            if value is not None:
+                odict[key] = value
         return odict
 
     def get_type(self):
@@ -194,19 +200,79 @@ class Song(dict, Logger):
         get_str(tag,xml=False)
         get a formated version of the tag "key"
         """
-        value = dict.get(self,"~"+key)
-        if not value: value = dict.get(self,key,"")
+        
+        if key == "uri":
+            value = vfs.fsdecode(vfs.unescape_string_for_display(self.get("uri")))
+        elif key == "title":
+            value = utils.format_tag(self.get("title"))
+            if not value:
+                value = vfs.fsdecode(vfs.unescape_string_for_display(self.get("uri")))
+                value = vfs.get_name(value)
+        elif key in ["album","genre","artist"]:
+            value = utils.format_tag(self.get(key))
+        elif key == "#bitrate":
+            value = self.get("#bitrate")
+            if value: 
+                value = "%dk"%value
+        elif key == "#duration":
+            value = utils.duration_to_string(self.get(key))
+        elif key == "#lastplayed":
+            value = self.get(key)
+            if value :
+                value = datetime.fromtimestamp(int(value)).strftime("%x %X")[:-3]
+            else:
+                value = _("Never")
+        elif key == "#playcount":
+            value = self.get(key) or _("Never")
+        elif key == "#date" or key == "#added":
+            value = self.get(key)
+            if value:
+                value = datetime.fromtimestamp(int(value)).strftime("%x %X")[:-3]
+        elif key == "#rate":
+            rate = self.get("rate")
+            if rate in [0,1,2,3,4,5,"0","1","2","3","4","5"]:
+                value = "rate-"+str(rate)
+            else:
+                value = "rate-0"
+        elif key == "date":
+            try:
+                value =  self.get("date", "")[:4]
+            except (ValueError, TypeError, KeyError): 
+                pass
+            if not value:
+                value = self.get("#date")
+                if value:
+                    value = datetime.fromtimestamp(int(value)).strftime("%Y")
+                else:
+                    value = ""
+        else:
+            value = None
+
+        if not value: value = self.get(key,"")
         if isinstance(value,int) or isinstance(value,float): value = "%d"%value
         try: value = unicode(value)
         except UnicodeDecodeError: 
-            print key,"===", value
+            print "EncError:",key,"===", value
             value = ""
         if xml: value = utils.xmlescape(value)
         return value
             
     def get_sortable(self,key):
-        try: value = dict.__getitem__(self,"~~~"+key)
-        except KeyError: value = dict.get(self,key)
+
+        if key == "uri":
+            value = self.get_str("uri").lower()
+        elif key in ["album","genre","artist","title"]:
+            value = utils.format_tag(self.get_str(key)).lower()
+        elif key == "radio_person":
+            value = self.get_str("radio_person")
+            if value : value = int(value.split("/")[0])
+            else: value = None
+        elif key == "date": 
+            value = self.get("#date")
+            # Ensure are None and not 0
+            if not value: value = None
+        else:
+            value = self.get(key)
 
         if not value and key[0] == "#" : value = 0
         elif not value: value = u'\xff\xff\xff\xff'
@@ -214,149 +280,44 @@ class Song(dict, Logger):
         return value
 
     def sanitarize(self):
-        #self.loginfo("sanitize %s"%self.get("uri"))
-        
-        for key in self.keys():
-            if key.startswith("~"):
-                dict.__delitem__(self,key)
-
-        self["uri"] = vfs.realuri(self.get("uri"))
-        
-        #Convert type
-        if self.has_key("##song_type##"):
-            del self["##song_type##"]
-
-        #Convertion of old podcast behavior from 0.5
-        if self.get("podcasturl"):
-            uri = self.get("podcasturl")
-            local_uri = self.get("uri")
-            del self["podcasturl"]
-            self["uri"] = uri
-            self["podcast_local_uri"] = local_uri
-            if self.get("#duration"):
-                self["#progress"] = 100
-            else:
-                self["#progress"] = -2
-
-        rss_url = self.get("podcastrss")
-        if rss_url: self["podcast_feed_url"] = rss_url
-        #descrss = self.get("description_rss")
-        #if descrss:
-        #    self["description"] = descrss
-        #    del self["description_rss"]
-
-        imagerss = self.get("imagerss")
-        if imagerss: self["album_cover_url"] = imagerss
-
-        added = self.get("#added")
-        if not added:
+        if "#added" not in self:
             self["#added"] = time()
-        date_rss = self.get("#rssdate")
-        if date_rss: self["#date"] = date_rss
 
-        date = self.get("date")
-        if date:
-            try: self["#date"] = utils.strdate_to_time(date)
-            except: print "W:Song Failed parse date" 
-               
-            del self["date"]
-        # End of convertion
+    def __setitem__(self, key, value):
+        if key == "#track":
+            if value is not None and not isinstance(value,int) and value.rfind("/")!=-1 and value.strip()!="":
+                value = value.strip()
 
-        track_nr = self.get("#track")
-        if track_nr is not None and not isinstance(track_nr,int) and track_nr.rfind("/")!=-1 and track_nr.strip()!="":
-            track_nr = track_nr.strip()
-            disc_nr = track_nr[track_nr.rfind("/"):]
-            track_nr = track_nr[:track_nr.rfind("/")]
-            dict.__setitem__(self, "#track", track_nr)
-            dict.__setitem__(self, "#disc", disc_nr)
+                disc_nr = value[value.rfind("/"):]
+                try: 
+                    disc_nr = int(disc_nr)
+                except: 
+                    disc_nr = self.get("#disc")
+                self["#disc"] = disc_nr
+                value = value[:value.rfind("/")]
+        elif key == "date":
+            try: 
+                self["#date"] = utils.strdate_to_time(value)
+            except: 
+                value = None
 
-        try: self["#disc"] = int(self.get("#disc"))
-        except: 
-            try: del self["#disc"]
-            except KeyError: pass
+        if key[0] == "#":
+            try:
+                if key in KEY_TYPES["float"]:
+                    value = float(value)
+                elif key in KEY_TYPES["long"]:
+                    value = long(value)
+                else:
+                    value = int(value)
+            except:
+                # WARNING: if value are wrong, it was suppressed! 
+                value = None
 
-        try: self["#track"] = int(self.get("#track"))
-        except: 
-            try: del self["#track"]
-            except KeyError: pass
-
-        for key in [ key for key in self.keys() if key[0]=="#"]:
-            value = self.get(key)
-            if isinstance(value,str) or isinstance(value,unicode):
-                try:
-                    if key in KEY_TYPES["float"]:
-                        dict.__setitem__(self, key, float(value))
-                    elif key in KEY_TYPES["long"]:
-                        dict.__setitem__(self, key, long(value))
-                    else:
-                        dict.__setitem__(self, key, int(value))
-                except:
-                    print "Failed set key ",key,"to", value ,"on song",self.get("uri")
-
-
-        filename = vfs.fsdecode(vfs.unescape_string_for_display(self.get("uri")))
-        dict.__setitem__(self,"~uri",filename)
-
-        title = self.get("title")
-        if not title: dict.__setitem__(self,"~title", filename )
-        else: dict.__setitem__(self,"~title", utils.format_tag(self.get("title")) )
-        
-        for key in ["album","genre","artist"]:
-            dict.__setitem__(self,"~"+key,utils.format_tag(self.get(key)))
-
-        if not self.get("#duration"): self["#duration"] = 0
-        #if self.get_type() in sType.podcast and self.get("~#date"):
-        #    dict.__setitem__(self, "~artist", self.get("~#date") )
-
-        bitrate = self.get("#bitrate")
-        if bitrate: dict.__setitem__(self,"~#bitrate", "%dk"%bitrate )
-        
-        [ dict.__setitem__(self,key,int(value)) \
-            for key,value in self.items() \
-                if key[0] == "#" and value ]
-
-        [ dict.__setitem__(self,"~"+key,"%d"%value) \
-            for key,value in self.items() \
-                if key[0] == "#" and value ]
-
-        dict.__setitem__(self,"~#duration",utils.duration_to_string(self.get("#duration")))
-
-        for key in ["#lastplayed","#playcount"]:
-            if not self.get(key):
-                dict.__setitem__(self,"~"+key,_("Never"))
-
-        for key in ["#lastplayed","#date"]:
-            if self.get(key):
-                dict.__setitem__(self,"~"+key,datetime.fromtimestamp(int(self.get(key))).strftime("%x %X")[:-3])
-
-        for key in ["#date"]:
-            if not self.get(key):
-                dict.__setitem__(self,"~"+key, _("Unknown"))
-
-        rate = self.get("#rate")
-        if rate in [0,1,2,3,4,5,"0","1","2","3","4","5"]:
-            dict.__setitem__(self,"~#rate","rate-"+str(rate))
+        if value is None:
+            if key in self:
+                dict.__delitem__(self, key)
         else:
-            dict.__setitem__(self,"~#rate","rate-0")
-
-        for key in ["album","genre","artist","title"]:
-            dict.__setitem__(self,"~~~"+key,utils.format_tag(self.get_str(key)).lower() )
-
-        dict.__setitem__(self, "~~~uri", self.get_str("uri").lower())
-
-        radio_person = self.get_str("radio_person")
-        if radio_person: dict.__setitem__(self, "~~~radio_person", int(radio_person.split("/")[0]) )
-        else:  dict.__setitem__(self, "~~~radio_person", None)
-
-        #cleanup not more used key
-        for key in [ key for key in self.keys() if key.replace("~","") not in USED_KEYS ]:
-            #print key, "unused"
-            del self[key]
-        
-    def __delitem__(self,delkey):
-        for key in [ key for key in self.keys() if key.replace("~","") == delkey.replace("~","") ]:
-            try: dict.__delitem__(self,key)
-            except KeyError: pass
+            dict.__setitem__(self, key, value)
 
     def __sort_key(self):   
         return(
@@ -381,13 +342,15 @@ class Song(dict, Logger):
                 self.get_sortable("uri")
                 )    
 #    browser_sort_key = property(__browser_sort_key)
+    
+    def __call__(self, key):
+        return self.get(key)
 
     def __hash__(self):
         return hash(self.get("uri"))
 
     def __repr__(self):
-        return self.get("uri")+","+self.get_str("title")+","+self.get_str("album")+","+self.get_str("artist")
-        return self.str_dump()
+        return "<Song %s>"%self.get("uri")
 
     def __cmp__(self, other):
         if not other: return -1 
