@@ -157,7 +157,8 @@ class ContextBox(gtk.HBox):
                 except gobject.GError: pixbuf = CoverManager.DEFAULT_COVER_PIXBUF
                 return (songs,markup,pixbuf)
             
-            albums_prefered = [(playcount,duration,album,songs) for key, (album,playcount,duration,songs) in self.__db_query.get_info("album",extended_info=True).iteritems() ]
+            data = self.__db_query.get_info("album",extended_info=True)
+            albums_prefered = [(playcount,duration,album,songs) for key, (album,playcount,duration,songs) in data.iteritems() ]
             albums_prefered.sort()
             albums_prefered.reverse()
             
@@ -289,8 +290,9 @@ class CurrentInfoBox(gtk.HBox):
                 try:pixbuf = CoverManager.get_pixbuf_from_song(songs[0], 40, 40, False)
                 except gobject.GError: pixbuf = CoverManager.DEFAULT_COVER_PIXBUF
                 return (songs,markup,pixbuf)
-
-            albums_prefered = [(playcount,duration,album,songs) for key, (album,playcount,duration,songs) in self.__db_query.get_info("album",artists=[cur_song.get_sortable("artist")],extended_info=True).iteritems() ]
+        
+            data = self.__db_query.get_info("album",artists=[cur_song.get_sortable("artist")],extended_info=True)
+            albums_prefered = [(playcount,duration,album,songs) for key, (album,playcount,duration,songs) in data.iteritems() ]
             albums_prefered.sort()
             albums_prefered.reverse()
         
