@@ -229,7 +229,7 @@ class IpodTransfertJob(Job):
                 gpod.itdb_cp_track_to_ipod(track, str(filename), None)
 
             path = gpod.itdb_filename_on_ipod(track)
-            song["uri"] = "file://"+path
+            song["uri"] = vfs.get_uri_from_path(path)
             self.__dw.add_to_cache(song["uri"],track)
                         
 
@@ -346,7 +346,7 @@ class IpodDevice(DeviceWrapper):
         pl = self.iget_playlist_podcasts()
         [ self.add_to_verif_cache(ListenDB.get_or_create_song(tags, "device_" + self.udi + "_podcast")) for tags in self.__get_all_tags(pl) ]
         [ self.addplaylist_cache(pl,ListenDB.create_playlist("device_" + self.udi, pl.name, \
-                [ ListenDB.get_song("file://"+gpod.itdb_filename_on_ipod(t)) for t in gpod.sw_get_playlist_tracks(pl) if gpod.itdb_filename_on_ipod(t)])) \
+                [ ListenDB.get_song(vfs.get_uri_from_path(gpod.itdb_filename_on_ipod(t))) for t in gpod.sw_get_playlist_tracks(pl) if gpod.itdb_filename_on_ipod(t)])) \
                 for pl in gpod.sw_get_playlists(self.__itdb) \
                 if not gpod.itdb_playlist_is_mpl(pl) and not gpod.itdb_playlist_is_podcasts(pl) ]
 
@@ -547,7 +547,7 @@ class IpodDevice(DeviceWrapper):
             track = self.__track_cache[song["uri"]]
             gpod.itdb_playlist_add_track(ipod_pl,track,-1)
         self.set_dirty()
-        uris = [ "file://"+gpod.itdb_filename_on_ipod(t) for t in gpod.sw_get_playlist_tracks(ipod_pl) if gpod.itdb_filename_on_ipod(t)]
+        uris = [ vfs.get_uri_from_path(gpod.itdb_filename_on_ipod(t)) for t in gpod.sw_get_playlist_tracks(ipod_pl) if gpod.itdb_filename_on_ipod(t)]
         callback(uris,*args_cb)
 
     def add_song(self,song,callback,*args_cb,**kwargs):
@@ -620,7 +620,7 @@ class IpodDevice(DeviceWrapper):
             if not path :
                 self.logwarn("failed read a track (%s)",tags)
                 return None
-            tags["uri"] = "file://"+path
+            tags["uri"] = vfs.get_uri_from_path(path)
             tags["#size"] = os.path.getsize(path)
 
             tags["ext_data"]= {}
