@@ -42,10 +42,38 @@ from widget.jobs_manager import Job
 from widget.misc import SimpleMenu
 
 from helper import SignalCollector
-from widget.dialog import WindowNewPodcast
+from widget.dialog import WindowNewPodcast, WindowConfirmation
+
+from widget.jobs_manager import Job
 
 IMPORT_SUBMIT = 200
 
+
+class BackgroundDeletePodcastsOperation(Job):
+    __message = _("Deleting podcasts...")
+    def __init__(self, songs=[] , from_disk=False):
+        self.songs = songs
+        self.from_disk = from_disk
+        self.message = _("Deleting podcasts...")
+        super(BackgroundDeletePodcastsOperation,self).__init__()
+ 
+    def job(self):
+        total = len(self.songs)
+        i = 0
+
+        for song in self.songs:
+            i += 1
+            if self.from_disk and song.get("podcast_local_uri"):
+                try:
+                    if not vfs.move_to_trash(song.get("podcast_local_uri")):
+                        self.logwarn("failed to move to trash %s ",song.get("podcast_local_uri"))
+                except:
+                    self.logexception("failed to move to trash %s ",song.get("podcast_local_uri"))
+            ListenDB.set_property(song,{"hidden":True, "#progress":0 })
+
+            yield _("Deleting podcasts") + " %d/%s"%(i,total),float(i)/float(total),False
+
+
 class PodcastSongView(SortableSongView):
     def __init__(self,conf_prefix):
         kargs = {
@@ -67,13 +95,16 @@ class PodcastSongView(SortableSongView):
 
     def __song_menu_action(self,song_menu_manager,id_menu,songs):
         if id_menu.startswith("podcast_delete"):
-            for song in songs:
-                ListenDB.set_property(song,{"hidden":True, "#progress":0 })
-                if id_menu == "podcast_deletedisk":
-                    if not vfs.move_to_trash(song.get("podcast_local_uri")):
-                        self.logwarn("failed to move to trash %s ",song.get("podcast_local_uri"))
-
-
+            if id_menu == "podcast_deletedisk":
+                text = _("Are you sure to move %d podcasts to your trash ?")
+                text = text%len(songs)
+                w = WindowConfirmation(text)
+                if w.run() == gtk.RESPONSE_ACCEPT:
+                    BackgroundDeletePodcastsOperation(songs, True)
+                w.destroy()
+            else:
+                BackgroundDeletePodcastsOperation(songs, False)
+            
 
 
 class PodcastBrowser(Browser):
@@ -297,7 +328,7 @@ class FeedsDownloadJob(Job):
             s = ListenDB.get_or_create_song(tags,"podcast")
             songs.append(s)
         songs = [ (song.get("#date"), song) for song in songs ]
-        songs.sort()
+        songs.sort(reverse = True)
         songs = [ song[1] for song in songs ]
         songs = songs[:int(float(config.get("podcast","nb_download")))]
         PodcastDownloadJob(songs)
