@@ -38,6 +38,7 @@ PREF_WIKIPEDIA = "source/wikipedia"
 SRC_UNKNOWN = 'source/unknown'
 SRC_BIBLIO = 'source/biblio'
 SRC_JAMENDO = 'source/jamendo'
+SRC_MAGNATUNE = 'source/magnatune'
 SRC_DAAP = 'source/biblio'
 SRC_IPOD = 'source/ipod'
 SRC_PLAYLIST = 'source/playlist'
@@ -49,14 +50,15 @@ SRC_WIKIPEDIA = "source/wikipedia"
 SRC_LASTFM = "source/lastfm_mini"
 SRC_PODCAST = "source/podcast"
 SRC_LYRICS = "source/lyrics"
+SRC_YOOOOK = "source/yooook"
 LASTFM_SIMILAR="source/lastfm_mini"
 
 
 
 _ICONS = [SRC_DAAP,LISTEN,MEDIA_LIB,LASTFM,WIKI_USERS,WIKI_CD,\
         PREF_OSD,PREF_PODCAST,PREF_LASTFM,\
-        SRC_BIBLIO,SRC_IPOD,SRC_PLAYLIST,SRC_PLAYLIST_IPOD,SRC_PODCAST_IPOD,\
-        SRC_IRADIO,SRC_WIKIPEDIA,SRC_LASTFM,SRC_PODCAST,SRC_LYRICS,SRC_PLAYLIST_SMART, SRC_JAMENDO, SRC_UNKNOWN, \
+        SRC_BIBLIO,SRC_IPOD,SRC_PLAYLIST,SRC_PLAYLIST_IPOD,SRC_PODCAST_IPOD,SRC_MAGNATUNE, \
+        SRC_IRADIO,SRC_WIKIPEDIA,SRC_LASTFM,SRC_PODCAST,SRC_LYRICS,SRC_YOOOOK,SRC_PLAYLIST_SMART, SRC_JAMENDO, SRC_UNKNOWN, \
         COVER]
 
 IMPORT_FOLDER = "importfolder"
@@ -70,6 +72,7 @@ PLAY = "play"
 WIKI_ARTIST = "wiki-artist"
 WIKI_ALBUM = "wiki-album"
 LYRICS = "lyrics"
+YOOOOK = "yooook"
 DELETE = "delete"
 DELETE_DISK = "delete-disk"
 MUSICBRAINZ = "musicbrainz"
@@ -112,6 +115,7 @@ def stock_init():
             (WIKI_ARTIST, _("About _artist"), 0, 0, ""),
             (WIKI_ALBUM, _("About a_lbum"), 0, 0, ""),
             (LYRICS, _("See _Lyrics"), 0, 0, ""),
+            (YOOOOK, _("_Liberate copyright"), 0, 0, ""),
             (DELETE, _('Remove'), 0, 0, ""),
             (DELETE_DISK, _('Move to trash'), 0, 0, ""),
             (SRC_PLAYLIST, _('_New Playlist'), 0, 0, ""),
@@ -154,6 +158,7 @@ def stock_init():
     factory.add(WIKI_ARTIST, lookup(gtk.STOCK_ABOUT))
     factory.add(WIKI_ALBUM, lookup(gtk.STOCK_ABOUT))
     factory.add(LYRICS, lookup(gtk.STOCK_EDIT))
+    factory.add(YOOOOK, lookup(SRC_YOOOOK))
     factory.add(DELETE, lookup(gtk.STOCK_REMOVE))
     factory.add(DELETE_DISK, lookup(gtk.STOCK_DELETE))
     factory.add(MUSICBRAINZ, lookup(gtk.STOCK_NETWORK))
