@@ -29,6 +29,8 @@ import gc
 
 from time import time,strptime, mktime
 
+from logger import logger
+
 def print_gc(obj):
     gc.collect()
     print gc.get_referrers(obj)
@@ -104,6 +106,12 @@ def export_playlist(list_song,filename,type="m3u"):
         fileout = open(filename, "w")
         [ fileout.write("file%d=%s\n"%(i,song.get_path()))  for i,song in enumerate(list_song)  if song.get_path() != None  ]
         fileout.close()
+    elif type=="xspf":
+        fileout = open(filename, "w")
+        fileout.write('<?xml version="1.0" encoding="UTF-8"?>\n<playlist version="0" xmlns = "http://xspf.org/ns/0/">\n<trackList>')
+        [ fileout.write("<track><location>%s</location></track>\n"%song.get("uri"))  for song in list_song if song.get("uri") != None  ]
+        fileout.write('  </trackList>\n</playlist>\n' )
+        fileout.close()
     else:
         raise TypeError, "Unknow playlist type"
 
@@ -223,7 +231,6 @@ def strdate_to_time(odate):
         try:
             return mktime(new_date)
         except :
-            from logger import logger
             logger.exception("problem to convert %s (%s) in date format",odate,new_date)
             return None
 
@@ -241,13 +248,12 @@ def load_db(fn):
     objs = None
     if os.path.exists(fn):
         f = file(fn, "rb")
-        objs = cPickle.load(f)
-        """try: objs = cPickle.load(f)
+        try: objs = cPickle.load(f)
         except:
-            print _("W: %s is not a Listen database.") % fn
+            logger.exception("%s is not a Listen database.", fn)
             try: shutil.copy(fn, fn + ".not-valid")
             except: pass
-            objs = None"""
+            objs = None
         f.close()
     return objs
 
