@@ -35,7 +35,7 @@ WEBSERVICE_CACHE_EXPIRATION = 1000*60*60*6
 
 TIMEOUT = 30
 
-class WebFetchThread:
+class WebFetchThread(object):
     def __init__(self,buffer_len,func_fail_cb,*args_fail_cb):
         self.id = len(THREAD_INSTANCE)
         THREAD_INSTANCE.append(self)
