@@ -107,11 +107,11 @@ class BrowserTagView(MultiDragTreeview,Logger):
         self.get_selection().set_mode(gtk.SELECTION_MULTIPLE)
 
 
-        iter = self.__model.insert(0, self.__get_tuple(KEY_ALL, "<b>%d %s</b>"%(0,self.__label), 0, None, None, escape = False) )
+        iter = self.__model.insert(0, self.__get_tuple(KEY_ALL, "<b>%d %s</b>"%(0,self.__label), 0, None, None, [], escape = False) )
         self.__ref_rows = {}
         [ self.__ref_rows.update({unicode(row[0]):row.path}) for row in self.__model ]
         
-    def __get_tuple(self,key,value,nb,playcount,duration,escape = True):
+    def __get_tuple(self,key,value,nb,playcount,duration, songs, escape = True):
         if self.__tag == "album":
             extra = CoverManager.get_pixbuf_from_album(value)
             if duration: duration = " - "+utils.duration_to_string(duration)
@@ -119,7 +119,14 @@ class BrowserTagView(MultiDragTreeview,Logger):
             if nb == 0 : str_song = _("song")
             else: str_song = _("songs")
             if escape: value = utils.xmlescape(value)
-            return (key,nb,"<b>%s</b>\n<i>%d %s%s</i>"%(value,nb,str_song,duration) , value.lower(), extra )
+            if songs and songs[0].get_type() != "podcast":
+                date = songs[0].get_str("date", True)
+                if date: date = " <i>(%s)</i>"%date
+                else: date = ""
+            else:
+                date = ""
+
+            return (key,nb,"<b>%s</b>%s\n<i>%d %s%s</i>"%(value,date, nb,str_song,duration) , value.lower(), extra )
         else:
             if escape: value = utils.xmlescape(value)
             return (key,nb,"%s (%d)"%(value,nb) , value.lower() )
@@ -137,6 +144,7 @@ class BrowserTagView(MultiDragTreeview,Logger):
             else:
                 playcount = None
                 duration = None
+                songs = []
                 if len(value) == 2:
 	                value ,nb = value
                 else:
@@ -149,9 +157,9 @@ class BrowserTagView(MultiDragTreeview,Logger):
                     escape = True
 
                 if not self.__ref_rows.has_key(key):
-                    self.__model.append( self.__get_tuple(key,value,nb,playcount, duration, escape = escape) )
+                    self.__model.append( self.__get_tuple(key,value,nb,playcount, duration, songs, escape = escape) )
                 else:
-                    self.__model[self.__ref_rows[key]] = self.__get_tuple(key,value,nb,playcount,duration, escape = escape)
+                    self.__model[self.__ref_rows[key]] = self.__get_tuple(key,value,nb,playcount,duration, songs, escape = escape)
 
         path_to_del.sort()
         path_to_del.reverse()
@@ -172,7 +180,7 @@ class BrowserTagView(MultiDragTreeview,Logger):
         if nb_keys > 1 : label = self.__labels
         else: label = self.__labels
 
-        self.__model[self.__ref_rows[KEY_ALL]] =  self.__get_tuple(KEY_ALL, "<b>%d %s</b>"%(nb_keys, label), total,None,None, escape = False)
+        self.__model[self.__ref_rows[KEY_ALL]] =  self.__get_tuple(KEY_ALL, "<b>%d %s</b>"%(nb_keys, label), total,None,None, [], escape = False)
         
 
         self.set_model(self.__model)
@@ -188,6 +196,7 @@ class BrowserTagView(MultiDragTreeview,Logger):
         for key in keys:
             playcount = None
             duration = None
+            songs = []
             if len(_dict[key]) == 2:
                 value, nb = _dict[key]
             else:
@@ -199,12 +208,12 @@ class BrowserTagView(MultiDragTreeview,Logger):
             else:
                 escape = True
             total += nb
-            self.__model.append( self.__get_tuple(key,value,nb,playcount,duration, escape = escape) )
+            self.__model.append( self.__get_tuple(key,value,nb,playcount,duration, songs, escape = escape) )
         
         nb_keys = len(_dict)
         if nb_keys > 1 : label = self.__labels
         else: label = self.__label
-        self.__model.insert(0, self.__get_tuple(KEY_ALL, "<b>%d %s</b>"%(nb_keys, label), total, None, None, escape = False) )
+        self.__model.insert(0, self.__get_tuple(KEY_ALL, "<b>%d %s</b>"%(nb_keys, label), total, None, None, [], escape = False) )
         [ self.__ref_rows.update({unicode(row[0]):row.path}) for row in self.__model ]
 
         self.set_model(self.__model)
@@ -629,10 +638,11 @@ class Browser(gtk.VBox,SignalContainer,Logger):
     def __popup_menu(self,widget,tag):
         model,rows = self._tree[tag].get_selection().get_selected_rows()
         if len(rows)<0: return
-        songs = self.__get_selected_songs(tag)
+        songs = list(self.__get_selected_songs(tag))
+        songs.sort()
 
         if self.menu and songs:
-            self.menu.popup(list(songs),custom_popup=tag, image = {"change_cover": CoverManager.get_cover( list(songs)[0], False)} )
+            self.menu.popup(songs,custom_popup=tag, image = {"change_cover": CoverManager.get_cover( songs[0], False)} )
         if self.empty_menu and not songs:
             self.empty_menu.popup([])
             
@@ -658,13 +668,6 @@ class Browser(gtk.VBox,SignalContainer,Logger):
         if self.empty_menu and hasattr(self.empty_menu,"autodisconnect_all") and callable(self.empty_menu.autodisconnect_all):
             self.empty_menu.autodisconnect_all()
 
-    def __del__(self):
-        pass
-        
-        #from utils import print_gc
-        #print_gc( self._tree["songs"])
-
-
 class SimpleBrowser(Browser):
     _type = "local"
     _config_code = "local"
