@@ -41,7 +41,6 @@ if proxy.has_key("http"):
 
 from song import Song
 from widget.dialog import WindowBase
-from widget.misc import set_tip
 from web_threading import WebFetchThread
 from player import Player
 
@@ -74,7 +73,7 @@ class CoverButton(gtk.EventBox):
 
         self.add(f)
 
-        set_tip(self,_("Right click: change cover\nLeft click: show big cover"))
+        self.set_tooltip_text(_("Right click: change cover\nLeft click: show big cover"))
 
         ListenDB.connect("simple-changed",self.update_cover)
 
@@ -356,7 +355,7 @@ class CoverWindow(WindowBase,Logger):
     def on_search_google_cb(self,html_handler,page):
         
         html = html_handler.read()
-        js_images = re.findall('[,\[]\[".*?,"1",\[\],""\]',html, re.S)
+        js_images = re.findall('\[\"/imgres[^"]*",\"[^"]*",\"[^"]*",\"([^"]*)",\"[^"]*",\"[^"]*",\"([^"]*)",\"[^"]*",\"[^"]*",\"([^"]*)",',html, re.S)
         if not js_images : 
             self.logwarn("Perhaps Google page structure has changed")
             self.fail_fetch()
@@ -370,19 +369,17 @@ class CoverWindow(WindowBase,Logger):
 
         items = []
         for jsimg in js_images:
-            info = [ info.replace('"','') for info in re.findall('".*?"', jsimg, re.S) ]
-            url = str(info[3])
-            title = info[6]
-            title = unicode(title,errors="ignore")
-            title = re.sub("<.*?>","",title)
-            items.append((url, title ,""))
-            
+            info = jsimg[1]
+            info = info.replace('\\x3cb\\x3e','')
+            info = info.replace('\\x3c/b\\x3e','')
+            url = str(jsimg[0])
+            title = jsimg[2]
+            items.append((url, title , info))            
         self.populate(page,items)
 
 
     def on_search_amazon(self,page):
         art = utils.remove_accents(self.entry.get_text().encode('utf-8'))
-        amazon.setLicenseKey("0RKH4ZH1JCFZHMND91G2")
 
         try: 
             pages = amazon.ItemSearch(art, "Music", Condition="All", MerchantId="All", Availability=None, ResponseGroup="Images,Request,Small" )
