@@ -92,7 +92,6 @@ class WinDir(gtk.FileChooserDialog):
              (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,gtk.STOCK_OPEN, gtk.RESPONSE_OK))
              
         self.set_modal(True)
-        import os
         self.set_current_folder(os.path.expanduser("~/"))
 
     def run(self):
@@ -256,23 +255,7 @@ class WindowExportPlaylist(gtk.FileChooserDialog):
              (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE, gtk.RESPONSE_OK))
              
         self.set_modal(True)
-        
-        """f1 = gtk.FileFilter()
-        f1.set_name(_("M3U files"))
-        f1.add_mime_type("audio/mpegurl")
-        f1.add_mime_type("audio/x-mpegurl")
-        f1.add_mime_type("audio/m3u")
-        f1.add_pattern("*.m3u")
-        
-        f2 = gtk.FileFilter()
-        f2.set_name(_("PLS files"))
-        f2.add_mime_type("audio/x-scpls")
-        f2.add_pattern("*.pls")
-        
-        self.add_filter(f1)
-        self.add_filter(f2)"""
-        self.set_current_name("playlist.m3u")
-        
+        self.set_current_name("playlist.xspf")
         self.set_current_folder(os.path.expanduser("~/"))
 
     def run(self):
@@ -280,7 +263,7 @@ class WindowExportPlaylist(gtk.FileChooserDialog):
         self.set_modal(True)
         if response == gtk.RESPONSE_OK:
              filename = self.get_filename()
-             if vfs.get_ext(filename) in [".m3u",".pls"]:
+             if vfs.get_ext(filename) in [".m3u",".pls",".xspf"]:
                  utils.export_playlist(self.songs,filename,vfs.get_ext(filename,False))
              else:
                  pl_type = ".m3u"
@@ -303,11 +286,12 @@ class WindowLoadPlaylist(gtk.FileChooserDialog):
         ffilter.add_mime_type("audio/x-mpegurl")
         ffilter.add_mime_type("audio/m3u")
         ffilter.add_mime_type("audio/x-scpls")
+        ffilter.add_mime_type("application/xspf+xml")
         ffilter.add_pattern("*.m3u")
         ffilter.add_pattern("*.pls")
+        ffilter.add_pattern("*.xspf")
         self.add_filter(ffilter)
         
-        import os
         self.set_current_folder(os.path.expanduser("~/"))
 
     def run(self):
