@@ -44,6 +44,7 @@ from widget.osd import Osd
 from widget.misc import ScrolledWindow
 from widget.playlist import PlaylistUI
 from widget.menubar import ListenMenuBar
+from widget.smart_playlist import SmartPlaylistWindow
 
 from xdg_support import get_xdg_pixmap_file
 from vfs import FileMonitor, async_parse_uris
@@ -169,13 +170,14 @@ class Listen(gtk.Window,Logger):
         Player.save_state()
         if not Player.is_paused(): Player.pause()
         self.tray.cacher()
-        self.tray.tray_image.set_from_file( get_xdg_pixmap_file("listen_tray_save.png") )
+        self.tray.set_tray_icon("listen_tray_save.png")
         # wait fadeout done
         gobject.timeout_add(500,self.__idle_quit)
             
     def __idle_quit(self,*param):
         print "Exiting..."
         Player.stop()
+        self.mmkeys.release()
         self.notify.close_notification()
         self.tray.cacher()
         config.set("window","pos_global_pane","%d"%self.global_box.get_position())
@@ -320,7 +322,9 @@ class Listen(gtk.Window,Logger):
         ListenDB.create_playlist("local","New Playlist")
         
     def new_playlist_smart(self,s):
-        ListenDB.create_autoplaylist("local","local","New Automatic Playlist")
+        pl = ListenDB.create_autoplaylist("local","local","New Automatic Playlist")
+        SmartPlaylistWindow(pl, True).run()
+
         
     def download_cover(self,w):
         from source.local import CoverDownloadJob
@@ -336,7 +340,7 @@ class Listen(gtk.Window,Logger):
         action = self.ui.get_action("/MenuBar/Control/playpause")   
         action.set_property("stock-id",stock)
         action.set_property("label",name)
-        self.tray.tray_image.set_from_file( get_xdg_pixmap_file(image) )
+        self.tray.set_tray_icon(image)
         
     def get_main_menu(self):
         menu = """
@@ -388,6 +392,7 @@ class Listen(gtk.Window,Logger):
               <menuitem action="previous"/>
               <menuitem action="next"/>
               <separator />
+              <menuitem action="random_reorder"/>
               <menuitem action="shuffle"/>
               <menuitem action="repeat"/>
             </menu>
@@ -436,7 +441,8 @@ class Listen(gtk.Window,Logger):
                       ('next', gtk.STOCK_MEDIA_NEXT, _('_Next'), "<Alt>Right","", self.player_control),
                       ('rewind', gtk.STOCK_MEDIA_REWIND, _('_Rewind'), "<Control>Left","", self.player_control),
                       ('forward', gtk.STOCK_MEDIA_FORWARD, _('_Forward'), "<Control>Right","", self.player_control),
-                      ("DownloadCover",None,_("Download missing cover"),None,"",self.download_cover)
+                      ("DownloadCover",None,_("Download missing cover"),None,"",self.download_cover),
+                      ('random_reorder', stock.SHUFFLE, _('_Shuffle'), "<control>u","", self.playlist_ui.playlist.random_reorder),
                       
                      ])
                      
@@ -460,17 +466,18 @@ class Listen(gtk.Window,Logger):
                                                      
         ag.add_toggle_actions([
            ('repeat', None, _('_Repeat'), "<control>r",None,None,config.getboolean("setting","repeat_mode")),
-           ('shuffle', stock.SHUFFLE, _('_Shuffle'), "<control>u",None,None,config.getboolean("setting","shuffle_mode")),
+           ('shuffle', stock.SHUFFLE, _('_Randomise playback'), None,None,None,config.getboolean("setting","shuffle_mode")),
            ('OfflineMode',None,_('Offline Mode'),None,None,None,config.getboolean("setting","offline"))
                       ])
+
+        b = ag.get_action("shuffle")
+        b.connect("toggled",self.playlist_ui.playlist.shuffle)
+        if config.getboolean("setting","shuffle_mode"): b.activate()
+
         b = ag.get_action("repeat")
         b.connect_proxy(self.playlist_ui.playlist_control.btn_repeat)
         if config.getboolean("setting","repeat_mode"): b.activate()
 
-        b = ag.get_action("shuffle")
-        b.connect_proxy(self.playlist_ui.playlist_control.btn_shuffle)
-        if config.getboolean("setting","shuffle_mode"): b.activate()
-
         b = ag.get_action("OfflineMode")
         def toggle_offline(w): 
             if w.get_active(): config.set("setting","offline","true")
