@@ -38,7 +38,7 @@ try:
 except: dbus_imported = False
 else: dbus_imported=True
 
-class Notify:
+class Notify(object):
     timeout = 10000
     current_song = None
     dbus_notify = None    
@@ -64,7 +64,9 @@ class Notify:
             #self.dbus_notify.connect_to_signal("NotificationClosed",self.on_notificationclosed)
 
             self.notify_server_info = self.dbus_notify.GetServerInformation()
-            if self.notify_server_info[0] == "Notify OSD":
+            self.notify_capabilities = self.dbus_notify.GetCapabilities()
+
+            if (self.notify_capabilities == None) or ("actions" in self.notify_capabilities):
                 self.actions = ["previous","Previous","next","Next"]
 
             Player.connect("instant-new-song",self.on_new_song)
@@ -104,7 +106,7 @@ class Notify:
                 text.append("<i>"+song.get_str("artist",True)+"</i>")
             if song.get("album"):
                 text.append(song.get_str("album",True))
-            text.append(utils.duration_to_string(value,"00:00")+" "+_("of")+" "+utils.duration_to_string(Player.get_length(),"00:00",1))
+            text.append(utils.duration_to_string(value, "00:00", 1)+" "+_("of")+" "+utils.duration_to_string(Player.get_length(),"00:00",1))
             
             text = "\n".join(text)
         else:
@@ -132,7 +134,7 @@ class Notify:
             getattr(Player, action)()
         
     def on_new_song(self,player,song):
-        if self.dbus_notify!=None and config.get("setting","notification")=="true" and not Player.is_paused():
+        if self.dbus_notify is not None and config.get("setting","notification") == "true":
             
             text = []
             if song.get_str("title"):
