@@ -190,15 +190,22 @@ class PlayerPlaylist(MultiDragTreeview):
         
     def load(self):
         songs = utils.load_db(get_xdg_config_file("playlist_cur.db"))
+        failed =False
         if songs:
             for song in songs:
-                ListenDB.get_or_create_song(song,song.get_type(),True)
-                self.add_song(song)
-        
-        self.__queue = utils.load_db( get_xdg_config_file("playlist_queue.db") )
-        if not self.__queue: self.__queue = []
+                try:
+                    ListenDB.get_or_create_song(song,song.get_type(),True)
+                    self.add_song(song)
+                except:
+                    failed = True
+
+        if not failed:
+            self.__queue = utils.load_db( get_xdg_config_file("playlist_queue.db") )
+            if not self.__queue or not isinstance(self.__queue, list): self.__queue = []
+            self.stop_track = config.getint("player", "stop_track")
+        else:
+            self.__queue = []
 
-        self.stop_track = config.getint("player", "stop_track")
         current_item = config.getint("player","selected_track")
         if current_item and current_item != -1 and current_item < len(self.get_model()):
             self.set_current_item(current_item)
@@ -219,7 +226,7 @@ class PlayerPlaylist(MultiDragTreeview):
         self.set_current_item(rows[0][0]) 
 
     #@utils.print_timing
-    def old_shuffle(self,w=None):
+    def random_reorder(self, *args):
         songs = self.get_songs()
         model = self.get_model()
         model.clear()
@@ -250,7 +257,7 @@ class PlayerPlaylist(MultiDragTreeview):
     def is_repeat(self):
         return config.getboolean("setting","repeat_mode")
 
-    def shuffle(self,w=None):
+    def shuffle(self, *args):
         if self.is_shuffle():
             config.set("setting","shuffle_mode","false")
         else:
@@ -440,9 +447,10 @@ class PlayerPlaylist(MultiDragTreeview):
         if self.current_item != -1 and self.current_item == self.stop_track:
             self.stop_track = -1
             return None
-        if len(self.__queue)>0:
+
+        if len(self.__queue) > 0:
             self.set_current_item(self.__queue.pop(0))
-        if self.is_shuffle():
+        elif self.is_shuffle():
             played = set(self._played)
             songs = set(range(len(model)))
             remaining = songs.difference(played)
@@ -462,7 +470,7 @@ class PlayerPlaylist(MultiDragTreeview):
         return self.get_current_song()
 
     def get_previous_song(self):
-        if Player.get_position() > 10000:
+        if Player.get_position() > 10:
             return Player.song
         
         if self.is_empty():
@@ -477,7 +485,8 @@ class PlayerPlaylist(MultiDragTreeview):
         if self.current_item > 0 :
             self.set_current_item( self.current_item - 1 )
         else:
-            self.set_current_item( len(model)-1 )
+            model = self.get_model()
+            self.set_current_item( len(model) - 1 )
 
         return self.get_current_song()
 
@@ -517,23 +526,21 @@ class PlayerPlaylist(MultiDragTreeview):
                 text += "<span background=\"red\" foreground=\"white\"><b> #%d </b></span> "%(self.__queue.index(path)+1)
             else:
                 text += "<span background=\"orange\" foreground=\"white\"><b> #%d </b></span> "%(self.__queue.index(path)+1)
-        text += "<span size=\"small\"><b>"
+        text += "<b>"
         if song.get("station"):
             text +=  song.get_str("station",True)+"\n"
         text +=  song.get_str("title",True)
-        text += "</b></span>"
+        text += "</b>"
         if config.get("setting","compact_playlist")=="true": 
             sep =" - "
         else: 
             text += "\n"    
             sep = ""
-        text += "<span size=\"small\">"
         if song.get_str("artist")!="":
             text += sep+"<i>"+song.get_str("artist",True)+"</i>"
             sep =" - "
         if song.get_str("album")!="":
             text += sep+song.get_str("album",True)
-        text += "</span>"
         if config.getboolean("setting", "dynamic_playlist_color"):
             data = self.calcSongColors(song)
             rgb = colorsys.hls_to_rgb(data[0], 0.78 + data[1], 0.90)
