@@ -21,8 +21,8 @@
 ###
 
 import gtk
-import md5
 import gst
+from hashlib import md5
 
 import os
 import stock
@@ -93,7 +93,7 @@ class HelperConfigureDialog(gtk.Window):
         self.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
         self.set_border_width(12)
         self.set_property("skip-taskbar-hint",True)
-        self.set_modal(False)
+        self.set_modal(True)
         self.set_transient_for(parent)
 
         btn = gtk.Button(stock=gtk.STOCK_CLOSE)
@@ -231,11 +231,16 @@ class HelperConfigureDialog(gtk.Window):
                           gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL), backend=None)
         file = gtk.FileChooserButton(dialog)
         path = config.get(section,attribut, default)
+
         if not path:
             path = "~"
         path = os.path.expanduser(path)
         if not os.path.exists(path):
-            os.makedirs(path)
+            try: 
+                os.makedirs(path)
+            except:
+                path = os.path.expanduser("~")
+
         file.set_current_folder(path)
         def save(dialog,response):
             if response==gtk.RESPONSE_ACCEPT:
@@ -534,9 +539,7 @@ class PreferenceDialog(HelperConfigureDialog):
         def save_entry(widget,sect,attr):
             if sect=="audioscrobbler" and attr=="password":
                 if widget.get_text()!="":
-                    hasher = md5.new()
-                    hasher.update(widget.get_text())
-                    md5_pass = hasher.hexdigest()
+                    md5_pass = md5(widget.get_text()).hexdigest()
                     config.set(sect,attr,md5_pass)
             else:
                 config.set(sect,attr,widget.get_text())
