@@ -147,14 +147,14 @@ class SongView(MultiDragTreeview,SignalContainer):
         kargs["genre"] = (_("Genre"), gobject.TYPE_STRING)
         kargs["artist"] = (_("Artist"), gobject.TYPE_STRING)
         kargs["album"] = (_("Album"), gobject.TYPE_STRING)
-        kargs["date"] = (_("Date"), gobject.TYPE_STRING)
+        kargs["date"] = (_("Year"), gobject.TYPE_STRING)
 
         kargs["#bitrate"] = (_("Bitrate"),gobject.TYPE_STRING) 
         kargs["#duration"] = (_("Length"),gobject.TYPE_STRING) 
         kargs["#playcount"] = (_("Play Count"),gobject.TYPE_STRING) 
         kargs["#skipcount"] = (_("Skip Count"),gobject.TYPE_STRING) 
         kargs["#lastplayed"] = (_("Last Played"),gobject.TYPE_STRING)     
-        kargs["#date"] = (_("Added"), gobject.TYPE_STRING)
+        kargs["#added"] = (_("Added"), gobject.TYPE_STRING)
         kargs["#disc"] = (_("Disc"), gobject.TYPE_STRING)
 
         return kargs
@@ -414,7 +414,7 @@ class PlaylistSongView(SongView):
                         i -= 1 
                 self.reorder_playlist()
                 
-            elif selection.target in ["text/listen-songs"]:#"text/uri-list", #DISABLE FOR NOW
+            elif selection.target in ["text/listen-songs","text/uri-list" ]:
                 if selection.data:
                     if drop_info:
                         new_pos, position = drop_info
