@@ -107,7 +107,7 @@ class SourceUI(gtk.VBox,Logger):
         self.motion_drag_current_path = None
         self.real_selected_row = None
         
-        targets = [("text/listen-songs", gtk.TARGET_SAME_APP, 1)]#,("text/uri-list", 0, 2)]
+        targets = [("text/listen-songs", gtk.TARGET_SAME_APP, 1), ("text/uri-list", 0, 2)]
         self.tree.enable_model_drag_dest(targets, gtk.gdk.ACTION_COPY)
         self.tree.enable_model_drag_source(gtk.gdk.BUTTON1_MASK, targets, gtk.gdk.ACTION_COPY)
         self.tree.connect("drag-data-get", self.on_drag_data_get)
@@ -494,17 +494,13 @@ class SourceUI(gtk.VBox,Logger):
         try : item = model[path][1]
         except : return
         
-        print item, selection.data
-        if not item or context.get_source_widget()==None :
-            pass
-        else:
-            if selection.data:
-                songs = []
-                for uri in  selection.data.splitlines():
-                    song = ListenDB.get_song(uri)
-                    if song :
-                        songs.append(song)
-                item.on_drag_song_received(songs)
+        if selection.data and item:
+            songs = []
+            for uri in  selection.data.splitlines():
+                song = ListenDB.get_song(uri)
+                if song :
+                    songs.append(song)
+            item.on_drag_song_received(songs)
         
         
     def __button_press(self, w,event):
