@@ -75,9 +75,7 @@ class SongTimer(gtk.HBox):
     def set_duration(self,player,song=None):
         if not song:
             if player.song: song = player.song
-            else: return 
-        if player.current_stream_seeked():
-            self.__need_report = False
+            else: return
         else:
             self.__need_report = True
         
@@ -102,11 +100,11 @@ class SongTimer(gtk.HBox):
                 self.bar.set_value(pos)
 
         if pos >= duration:
-            text = utils.duration_to_string(pos*1000,"00:00")
+            text = utils.duration_to_string(pos, "00:00", 1)
         else:
-            text = utils.duration_to_string(pos*1000,"00:00")+" "+_("of")+" "+utils.duration_to_string(duration*1000,"00:00")
+            text = utils.duration_to_string(pos, "00:00", 1 )+" "+_("of")+" "+utils.duration_to_string(duration*1000,"00:00")
         self.label_time.set_label("<span size=\"small\">"+text+"</span>")
-        if self.__need_report and duration>10 and pos >= min(duration/2, 240*1000):
+        if self.__need_report and duration>10 and pos >= min(duration/2, 240*1000) and not Player.current_stream_seeked():
             self.__need_report = False
             s = Player.song
             if s:
